ClinPhen is a free-to-use tool that automatically extracts phenotypes from clinical notes.

To get started:
clinphen --setup

To extract phenotypes:
clinphen <path_to_clinincal_note_file>

To see how to use other features:
clinphen --help
